********************
********************
**
**   Source File ... ALT_Func.PRG
**
**   Application ... SOS Help! v1.25b
**                   Copyright (c) 1988-1992 Lamaura Development Limited
**                   All Rights Reserved
**
**   Author ........ Philip de Lisle
**   Last Update ... 20 October 1992 at 1:25am
**   Purpose ....... Alternative to SOS_FUNC.PRG using Static/Global Help
**                   Variables
**
********************
********************

/*

  To set help within ACHOICE(), TBROWSE(), MEMOEDIT() etc, you need to set
  up some global variables. These are kept as STATICs in this .PRG. To
  access them you call SetHelpVars(), passing strings or variables as
  parameters.

  Passing variables by reference (ie preceding them with "@") causes the
  current value of the global variable to be assigned to the parameter
  variable. Thus you can nest global variables to any depth you like.

  Examples
  --------

     SetHelpVars('MyTBrowse', 'MyTBrowse')

     SetHelpVars(cHelpProc, cHelpVar)        // set globals to value of these
                                             // variables

     SetHelpVars(@cHelpProc, @cHelpVar)      // set globals to value of these
                                             // variables and return previous
                                             // settings in these variables

     SetHelpVars('', '')                     // Clear global variables


  NOTE :- The existing system does NOT use H_Line()

*/

/*

  If you are using a code generator such as SyceroDB, you cannot use 
  SetHelpVars() because you have no control over the generated source code.  

  If you are using SyceroDB, uncomment the #DEFINE SYCERODB below.

  If you are using another code generator which has a similar UDF to 
  PROGRAMNAME() (which returns then name of the currently executing .PRG), 
  change H_Name() accordingly.

*/

*#define SYCERODB         // uncomment this line if you are using SyceroDB

STATIC gcProc := '', gcVar := ''

FUNCTION H_Name(t_name)
#ifndef SYCERODB
  IF (! ((TRIM(t_name) == '_STYLE') .OR. (TRIM(t_name) == '_DEFAULT'))) .AND. ;
      (! EMPTY(gcProc))
    t_name := gcProc
  ENDIF
#else
  IF (! ((TRIM(t_name) == '_STYLE') .OR. (TRIM(t_name) == '_DEFAULT'))) 
    t_name := PROGRAMNAME()  // internal SyceroDB UDF
  ENDIF
#endif  
RETURN ( LEFT(UPPER( t_name )+SPACE(10),10) )


FUNCTION H_Line(t_line)
RETURN (t_line)


FUNCTION H_Var(t_var)
#ifndef SYCERODB
  IF (! ((TRIM(t_var) == '_STYLE') .OR. (TRIM(t_var) == '_DEFAULT'))) .AND. ;
      (! EMPTY(gcVar))
    t_var := gcVar
  ENDIF
#endif
RETURN ( LEFT(UPPER( t_var )+SPACE(10),10) )


//
//  This UDF does all the work
//
FUNCTION SetHelpVars(cProc, cVar)

LOCAL cOldProc, cOldVar

IF VALTYPE(cVar) = NIL
   cVar := cProc
ENDIF

cOldProc := gcProc     // save old value so that is can be passed back if
cOldVar  := gcVar      // called by reference

gcProc := IIF(EMPTY(cProc), '', cProc)
gcVar  := IIF(EMPTY(cVar), '', cVar)

cProc := cOldProc
cVar  := cOldVar

RETURN (nil)


*|
*|  H_Color() allows you to set colors for your help screens which are
*|  EXTERNAL to the .HLP file.  This UDF is only active in the BINARY model
*|

#include 'sos_help.ch'    //  contains the manifest constants required

FUNCTION H_Color(cColor, nID)

/*  UNCOMMENT THIS SECTION TO ASSIGN EXTERNAL, FIXED COLORS TO YOU HELP SCREENS
DO CASE
   CASE nID = BOX_COLOR
        cColor = '+gr/b'
   CASE nID = SHAD_COLOR
        cColor = 'g/w'
   CASE nID = TEXT_COLOR
        cColor = '+w/br'
   CASE nID = TITLE_COLOR
        cColor = '+r/bg'
ENDCASE
*/

RETURN (cColor)


FUNCTION GetItemForHelp(nSize)
**
** Syntax ..... GETITEMFORHELP(<N>)
**
** Purpose .... Get the Name of the Selected Item from an ACHOICE/TBROWSE
**
** Argument ... <N> = Max Length of the Item
**
** Returns .... Character
**

LOCAL i, nX, nY, cBuffer

nX := COL()
nY := ROW()

cBuffer := SAVESCREEN(nY,nX,nY,(nX+nSize-1))

FOR i := (nSize * 2) TO 1 STEP -2       // strip out all the attribute info
    cBuffer := STUFF(cBuffer, i, 1, '')
NEXT

SetHelpVars(gcProc, cBuffer)   // NEVER change the Procedure Name

RETURN (NIL)
*| EOF GetItemForHelp

*|----------------------------------------------------------------------------|*
*|----------------------------------------------------------------------------|*
*|----------------------------------------------------------------------------|*
*|----------------------------------------------------------------------------|*

*|
*|  Change this portion of the code if you wish to use RDD's or configure the
*|  help database handling characteristics.
*|

function SOS_Use(cName)
**
** Syntax ..... SOS_USE(<C>)
**
** Purpose .... Open .DBF with RDD support
**
** Argument ... <C> = .DBF Name
**
** Returns .... Nothing
**
** Note ....... *NEVER* change the ALIAS clauses as these are used internally.
**
**              The SOS Help! help table is *ALWAYS* opened in exclusive mode
**              regardless of the setting of the SET EXCLUSIVE command, unless
**              you have purchased a multi-user version of SOS Help!
**

use (cName) alias SOS_HELP

return (nil)
*| EOF SOS_Use

*|----------------------------------------------------------------------------|*

function SOS_Index(cExp, cIndex)
**
** Syntax ..... SOS_INDEX(<C1>, <C2>)
**
** Purpose .... Index Table to Index File/Tag
**
** Argument ... <C1> = Index Expression
**              <C2> = Index File/Tag Name
**
** Returns .... Nothing
**

index on &cExp to (cIndex)

return (nil)
*| EOF SOS_Index

*|----------------------------------------------------------------------------|*

function SOS_SetIndex(cIndex)
**
** Syntax ..... SOS_INDEX(<C>)
**
** Purpose .... Open Index File
**
** Argument ... <C> = Index File Name
**
** Returns .... Nothing
**

set index to (cIndex)

return (nil)
*| EOF SOS_Index

*|----------------------------------------------------------------------------|*
